@@ -10,8 +10,14 @@ import pandas as pd
 import math, matplotlib
 from itertools import cycle, islice
 import coreferee
+
+
 nlp = spacy.load('en_core_web_lg')
-nlp.add_pipe('coreferee')
+try:
+  nlp.add_pipe('coreferee')
+except:
+  print('Coreference is not available!!!')
+
 
 
 ## -- avnn edges-- ##
@@ -150,8 +156,8 @@ def keynet(all_edges1,heading='avN_N Network',core_K =1,plot_graph = True,save_a
     
     if plot_graph:
         nt.show_buttons(filter_=['physics']) 
-        nt.show("network_map.html")
-        display(HTML('network_map.html'))
+        nt.show("network_avnn.html")
+        display(HTML('network_avnn.html'))
     if save_add:      
         nt.save_graph(save_add)
     # all_edges after k-core of all_edges1
@@ -208,8 +214,8 @@ def communet(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,save_
       #ntc.add_edge(edge[0][:-2],edge[1][:-2], title = elabel,width = value)
     if plot_graph:
         ntc.show_buttons(filter_=['physics'])  
-        ntc.show('example1.html')
-        display(HTML('example1.html'))
+        ntc.show('community_network.html')
+        display(HTML('community_network.html'))
     if save_add:
         ntc.save_graph(save_add)
         
@@ -321,8 +327,8 @@ def communet_nnc(partition,iGd,Gdc,all_edges,colorList_rgba1,plot_graph = True,s
 
     if plot_graph:
         ntc2.show_buttons(filter_=['physics'])  
-        ntc2.show('example2.html')
-        display(HTML('example2.html'))
+        ntc2.show('communityNNcolor.html')
+        display(HTML('communityNNcolor.html'))
     if save_add:
         ntc2.save_graph(save_add)
 
@@ -421,8 +427,8 @@ def gray_unit(nnColor_df,Gdc,all_edges,comLen = False,plot_graph = False, save_f
       if plot_graph:
         ntc3.show_buttons(filter_=['physics']) 
         if community_index == com_len-1: 
-            ntc3.show(str(community_index) + 'example3.html')
-            display(HTML(str(community_index) + 'example3.html'))
+            ntc3.show(str(community_index) + '_gray_unit.html')
+            display(HTML(str(community_index) + '_gray_unit.html'))
       if save_folder:
         ntc3.save_graph(save_folder+ '/{}.html'.format(community_index +1))
 
