@@ -2,8 +2,13 @@
 import pandas as pd 
 import re ,spacy
 import coreferee
+
 nlp = spacy.load('en_core_web_lg')
-nlp.add_pipe('coreferee')
+try:
+  nlp.add_pipe('coreferee')
+except:
+  print('Coreference is not available!!!')
+    
 
 #1 count frequence of list
 def countFreq(my_list,extra_name=""):
