@@ -3,8 +3,7 @@ import pandas as pd
 import re 
 import coreferee, spacy
 from spacy import displacy
-nlp = spacy.load('en_core_web_lg')
-nlp.add_pipe('coreferee')
+
 
 from autocorrect import Speller
 import re
@@ -15,6 +14,7 @@ import matplotlib.pylab as plt
 import networkx as nx
 from matplotlib.pyplot import figure, text
 
+
 ## negative, conative verbs, non opinion adjective, arcticle, ordinal words
 
 
@@ -24,8 +24,8 @@ neg_words = ['hardly', 'scarcely','barely','no','not','none','neither','nor','ne
 #textneg = "I do not like you never know it be not really pretty, it means no money no girl, I hardly learn in the never nice school"
 #text =""" I don't like this High-quality hotel, /the\ restaraunt food is so ugly and expensive, United states of America next time we will go to New York, "good-good"  the place called "long islands",but I never hate it, it was not pretty,so I don't recommend it."""
 
-timedate = ['thing','things','issues','issue','parts','part','lots','lot','years','weeks','months',"hours",'date','hour','minute','year','week','month',"minutes","ones","one"]
-non_opi_adjs0 =["pengy","same","similar","different","another","other","half", "some", "several", "much", "all", "many", "whole","enough", "little", "sufficient", "most","least","few", "own","very","this", "that", "these", "those","each", "every","any","less","more","only",'next','previous','least','first','second','third','able','last','such','main','really','late','early','possible','due',] # number are deleted separtely 
+nounDEL = ['thing','things','issues','issue','parts','part','lots','lot','years','weeks','months',"hours",'date','hour','minute','year','week','month',"minutes","ones","one"]
+adjDEL =["same","similar","different","another","other","half", "some", "several", "much", "all", "many", "whole","enough", "little", "sufficient", "most","least","few", "own","very","this", "that", "these", "those","each", "every","any","less","more","only",'next','previous','least','first','second','third','able','last','such','main','really','late','early','possible','due',] # number are deleted separtely 
 #timedate = timedate0 + non_opi_adjs
 #timedate.remove('pengy')
 art_ordinal = ["a","an","the",'first','second','third','fourth','fifth','sixth','seventh','eighth','ninth','tenth','elventh','twelvth','e','o']
@@ -37,28 +37,40 @@ art_ordinal = ["a","an","the",'first','second','third','fourth','fifth','sixth',
         "distributive": ["each", "every", "either", "neither", "any"],
         "article": ["a", "an", "the"],"""
 
-aa = neg_words
-bb = non_opi_adjs0
-#print(len(bb))
-non_opi_adjs1 = []
-for a in aa:
-  for b in bb:
-    ab= a+b
-    non_opi_adjs1.append(ab)
-#print(len(non_opi_adjs1))
-non_opi_adjs = non_opi_adjs0 +non_opi_adjs1
-#print(len(non_opi_adjs))
+def negADJ(neg_words,adjDEL):
+  aa = neg_words
+  bb = adjDEL + ['pengy','ok']
+  #print(len(bb))
+  non_opi_adjs1 = []
+  for a in aa:
+    for b in bb:
+      ab= a+b
+      non_opi_adjs1.append(ab)
+  #print(len(non_opi_adjs1))
+  non_opi_adjs = adjDEL +non_opi_adjs1 +['pengy','ok'] # pengy is a temperal adjective 
+  #print(len(non_opi_adjs))
+  return non_opi_adjs
 
 
 
 
+nlp = spacy.load('en_core_web_lg')
+try:
+  nlp.add_pipe('coreferee')
+except:
+  print('Coreference is not available!!!')
 
 
-
-
-
-def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True,nncompound = False):
-
+def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True, opi_verbs = opi_verbs ,neg_words = neg_words, nounDEL =nounDEL, adjDEL = adjDEL,nncompound = False,):
+  """
+  include_otherEdge: greedy edges of the unmatched adj, verb, noun 
+  only_otherNouns: does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
+  nounDEL : nouns to be removed 
+  adjDEL : adjective to be removed 
+  """
+  non_opi_adjs = negADJ(neg_words,adjDEL)
+  
+  
   # 1. check spelling 
 
   #from autocorrect import Speller
@@ -80,7 +92,7 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
   for token in nlp(text1):
     if token.pos_ == "NUM":
       text1 = re.sub(r'\b' + token.text + r'\b',"  pengy  ", text1)  # space in case make new compund 
-  for td in timedate:
+  for td in nounDEL:
     text1 = text1.replace(td," , ")
     text1 = text1.replace(td.capitalize()," , ")
   if verbose_text:
@@ -142,18 +154,30 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
     mapnoun(" ".join(ncomp1))
 
     # coreference no lemmatize text 
-    text2 = coref(text2c)
+    try:
+      text2 = coref(text2c)
+      if verbose_text:
+        print('text2 correference: ', text2)
+    except:
+      text2 = text2c
+      if verbose_text:
+        print('text2: ', text2)
     #text2 = lemma_en(text2)
-    if verbose_text:
-      print('text2 correference: ', text2)
+
 
   else: 
     ncomp0,ncomp1 = [],[]  
     # coreference no lemmatize text 
-    text2 = coref(text2b)
+    try:
+      text2 = coref(text2b)
+      if verbose_text:
+        print('text2 correference: ', text2)
+    except:
+      text2 = text2b
+      if verbose_text:
+        print('text2: ', text2)
     #text2 = lemma_en(text2)
-    if verbose_text:
-      print('text2 correference: ', text2)
+
 
 
   #4. --- negverb, negadj --- 
@@ -361,7 +385,7 @@ def text2edges(text,verbose = False, verbose_text= False,include_otherEdge = Fal
 
   ##  --- all edges --- ## 
   if include_otherEdge:
-    if only_otherNouns: # does not have other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
+    if only_otherNouns: # does not have adjverb in other2N_edges other than av2n, the other2N_edeges are greedy to mach the rest adj, verb, noun instead of considering match pattern
       all_adjV2N_edges = adjV2N_edges
       allNNedges = allNN_edges0
     else:
@@ -425,8 +449,8 @@ def targList(mylist):
 
 #from autocorrect import Speller
 #from collections import defaultdict
-def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,only_opiAV = True,nncompound = False):
-
+def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = False, only_otherNouns = False,neg_words =neg_words,adjDEL = adjDEL,only_opiAV = True,nncompound = False):
+  non_opi_adjs = negADJ(neg_words,adjDEL)
   # 1. check spelling 
 
   #from autocorrect import Speller
@@ -448,7 +472,7 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
   for token in nlp(text1):
     if token.pos_ == "NUM":
       text1 = re.sub(r'\b' + token.text + r'\b',"  pengy  ", text1)  # space in case make new compund 
-  for td in timedate:
+  for td in nounDEL:
     text1 = text1.replace(td," , ")
     text1 = text1.replace(td.capitalize()," , ")
   if verbose_text:
@@ -510,18 +534,28 @@ def target2edges(text,verbose = False, verbose_text= False,include_otherEdge = F
     mapnoun(" ".join(ncomp1))
 
     # coreference no lemmatize text 
-    text2 = coref(text2c)
+    try:
+      text2 = coref(text2c)
+      if verbose_text:
+        print('text2 correference: ', text2)
+    except:
+      text2 = text2c
+      if verbose_text:
+        print('text2: ', text2)
     #text2 = lemma_en(text2)
-    if verbose_text:
-      print('text2 correference: ', text2)
 
   else: 
     ncomp0,ncomp1 = [],[]  
     # coreference no lemmatize text 
-    text2 = coref(text2b)
+    try:
+      text2 = coref(text2b)
+      if verbose_text:
+        print('text2 correference: ', text2)
+    except:
+      text2 = text2b
+      if verbose_text:
+        print('text2: ', text2)
     #text2 = lemma_en(text2)
-    if verbose_text:
-      print('text2 correference: ', text2)
 
 
   #4. --- negverb, negadj --- 
